@@ -675,14 +675,14 @@ pub fn cli<'a>() -> App<'a> {
                     .multiple(false)
                     .index(1)
                     .value_name("PKG")
-                    .about("Verify the sources of this package (optional, if left out, all packages are checked)")
+                    .about("Download the sources of this package (optional, if left out, all packages are downloaded)")
                 )
                 .arg(Arg::new("package_version")
                     .required(false)
                     .multiple(false)
                     .index(2)
                     .value_name("VERSION_CONSTRAINT")
-                    .about("Verify the sources of this package version (optional, if left out, all packages are checked)")
+                    .about("Download the sources of this package version (optional, if left out, all packages are downloaded)")
                 )
                 .arg(Arg::new("force")
                     .required(false)
